Event Dispatcher 
________________

The class that Handles Event dispatching in ``fbchat-muqit`` library. 


.. autoclass:: fbchat_muqit.EventDispatcher
   :members:
   :show-inheritance:
   :exclude-members: event, dispatch


